@@ -6,9 +6,9 @@ from allauth.socialaccount.models import SocialToken
 
 
 ALLOWED_PATHS = [
-    re.compile(r'^repos/([\w\.\-@_]+)/([\w\.\-@_]+)/contents/'),
-    re.compile(r'^user/repos$'),
-    re.compile(r'^repos/([\w\.\-@_]+)/([\w\.\-@_]+)/git/blobs/([\w\d]+)$'),
+    re.compile(r"^repos/([\w\.\-@_]+)/([\w\.\-@_]+)/contents/"),
+    re.compile(r"^user/repos$"),
+    re.compile(r"^repos/([\w\.\-@_]+)/([\w\.\-@_]+)/git/blobs/([\w\d]+)$"),
 ]
 
 
@@ -16,31 +16,25 @@ class Proxy(DjangoHandlerMixin, RequestHandler):
     async def get(self, path):
         user = self.get_current_user()
         social_token = SocialToken.objects.filter(
-            account__user=user,
-            account__provider='github'
+            account__user=user, account__provider="github"
         ).first()
         if (
-            not any(regex.match(path) for regex in ALLOWED_PATHS) or
-            not social_token or
-            not user.is_authenticated
+            not any(regex.match(path) for regex in ALLOWED_PATHS)
+            or not social_token
+            or not user.is_authenticated
         ):
             self.set_status(401)
             self.finish()
             return
         headers = {
-            'Authorization': 'token {}'.format(social_token.token),
-            'User-Agent': 'Fidus Writer'
+            "Authorization": "token {}".format(social_token.token),
+            "User-Agent": "Fidus Writer",
         }
         query = self.request.query
-        url = 'https://api.github.com/{}'.format(path)
+        url = "https://api.github.com/{}".format(path)
         if query:
-            url += '?' + query
-        request = HTTPRequest(
-            url,
-            'GET',
-            headers,
-            request_timeout=120
-        )
+            url += "?" + query
+        request = HTTPRequest(url, "GET", headers, request_timeout=120)
         http = AsyncHTTPClient()
         try:
             response = await http.fetch(request)
@@ -58,31 +52,26 @@ class Proxy(DjangoHandlerMixin, RequestHandler):
     async def put(self, path):
         user = self.get_current_user()
         social_token = SocialToken.objects.filter(
-            account__user=user,
-            account__provider='github'
+            account__user=user, account__provider="github"
         ).first()
         if (
-            not any(regex.match(path) for regex in ALLOWED_PATHS) or
-            not social_token or
-            not user.is_authenticated
+            not any(regex.match(path) for regex in ALLOWED_PATHS)
+            or not social_token
+            or not user.is_authenticated
         ):
             self.set_status(401)
             self.finish()
             return
         headers = {
-            'Authorization': 'token {}'.format(social_token.token),
-            'User-Agent': 'Fidus Writer'
+            "Authorization": "token {}".format(social_token.token),
+            "User-Agent": "Fidus Writer",
         }
         query = self.request.query
-        url = 'https://api.github.com/{}'.format(path)
+        url = "https://api.github.com/{}".format(path)
         if query:
-            url += '?' + query
+            url += "?" + query
         request = HTTPRequest(
-            url,
-            'PUT',
-            headers,
-            body=self.request.body,
-            request_timeout=120
+            url, "PUT", headers, body=self.request.body, request_timeout=120
         )
         http = AsyncHTTPClient()
         try:
